from pursuitlib.console.textcolor import TextColor


class TextColors:
    BLACK = TextColor.standard(30)
    DARK_RED = TextColor.standard(31)
    DARK_GREEN = TextColor.standard(32)
    DARK_YELLOW = TextColor.standard(33)
    DARK_BLUE = TextColor.standard(34)
    DARK_MAGENTA = TextColor.standard(35)
    DARK_CYAN = TextColor.standard(36)
    LIGHT_GRAY = TextColor.standard(37)
    DARK_GRAY = TextColor.standard(90)
    LIGHT_RED = TextColor.standard(91)
    LIGHT_GREEN = TextColor.standard(92)
    LIGHT_YELLOW = TextColor.standard(93)
    LIGHT_BLUE = TextColor.standard(94)
    LIGHT_MAGENTA = TextColor.standard(95)
    LIGHT_CYAN = TextColor.standard(96)
    WHITE = TextColor.standard(97)
